@@ -92,8 +92,7 @@ bool GmmLib::GmmResourceInfoCommon::CopyClientParams(GMM_RESCREATE_PARAMS &Creat
                         // Default Tiling is set to Tile64 on FtrTileY disabled platforms
                         uint8_t IsYUVSurface = ((GmmIsPlanar(CreateParams.Format) &&
                                                  (!((CreateParams.Format == GMM_FORMAT_BGRP) || (CreateParams.Format == GMM_FORMAT_RGBP)))) ||
-                                                (GmmIsYUVPacked(CreateParams.Format) &&
-                                                 !((CreateParams.Format == GMM_FORMAT_YVYU_2x1) || (CreateParams.Format == GMM_FORMAT_UYVY_2x1) || (CreateParams.Format == GMM_FORMAT_UYVY_2x1))));
+                                                (GmmIsYUVPacked(CreateParams.Format)));
 
 			CreateParams.Flags.Info.Tile4 = ((!GMM_IS_SUPPORTED_BPP_ON_TILE_64_YF_YS(BitsPerPixel)) ||            // 24,48,96 bpps are not supported on Tile64, Tile4 is bpp independent
                                                          ((CreateParams.Type == RESOURCE_3D) && (CreateParams.Flags.Gpu.Depth || CreateParams.Flags.Gpu.SeparateStencil)) ||
@@ -288,6 +287,8 @@ bool GmmLib::GmmResourceInfoCommon::CopyClientParams(GMM_RESCREATE_PARAMS &Creat
         {
             GMM_SET_64KB_TILE(Surf.Flags, 0, GetGmmLibContext());
             GMM_SET_4KB_TILE(Surf.Flags, 1, GetGmmLibContext());
+            GMM_SET_64KB_TILE(CreateParams.Flags, 0, GetGmmLibContext());
+            GMM_SET_4KB_TILE(CreateParams.Flags, 1, GetGmmLibContext());
         }
     }
 
